==> aws-cdk.aws-stepfunctions-tasks-1.89.0.tar.gz: package/lib/glue/run-glue-job-task.d.ts <==
import * as sfn from '@aws-cdk/aws-stepfunctions';
import { Duration } from '@aws-cdk/core';
/**
 * (deprecated) Properties for RunGlueJobTask.
 *
 * @deprecated use `GlueStartJobRun`
 */
export interface RunGlueJobTaskProps {
    /**
     * (deprecated) The service integration pattern indicates different ways to start the Glue job.
     *
     * The valid value for Glue is either FIRE_AND_FORGET or SYNC.
     *
     * @default FIRE_AND_FORGET
     * @deprecated
     */
    readonly integrationPattern?: sfn.ServiceIntegrationPattern;
    /**
     * (deprecated) The job arguments specifically for this run.
     *
     * For this job run, they replace the default arguments set in the job definition itself.
     *
     * @default - Default arguments set in the job definition
     * @deprecated
     */
    readonly arguments?: {
        [key: string]: string;
    };
    /**
     * (deprecated) The job run timeout.
     *
     * This is the maximum time that a job run can consume resources before it is terminated and enters TIMEOUT status.
     * Must be at least 1 minute.
     *
     * @default - Default timeout set in the job definition
     * @deprecated
     */
    readonly timeout?: Duration;
    /**
     * (deprecated) The name of the SecurityConfiguration structure to be used with this job run.
     *
     * This must match the Glue API
     * [single-line string pattern](https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-common.html#aws-glue-api-regex-oneLine).
     *
     * @default - Default configuration set in the job definition
     * @deprecated
     */
    readonly securityConfiguration?: string;
    /**
     * (deprecated) After a job run starts, the number of minutes to wait before sending a job run delay notification.
     *
     * Must be at least 1 minute.
     *
     * @default - Default delay set in the job definition
     * @deprecated
     */
    readonly notifyDelayAfter?: Duration;
}
/**
 * (deprecated) Invoke a Glue job as a Task.
 *
 * OUTPUT: the output of this task is a JobRun structure, for details consult
 * https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-runs.html#aws-glue-api-jobs-runs-JobRun
 *
 * @see https://docs.aws.amazon.com/step-functions/latest/dg/connect-glue.html
 * @deprecated use `GlueStartJobRun`
 */
export declare class RunGlueJobTask implements sfn.IStepFunctionsTask {
    private readonly glueJobName;
    private readonly props;
    private readonly integrationPattern;
    /**
     * @deprecated
     */
    constructor(glueJobName: string, props?: RunGlueJobTaskProps);
    /**
     * (deprecated) Called when the task object is used in a workflow.
     *
     * @deprecated
     */
    bind(task: sfn.Task): sfn.StepFunctionsTaskConfig;
}

==> aws-cdk.aws-stepfunctions-tasks-1.117.0.tar.gz: package/lib/glue/run-glue-job-task.d.ts <==
import * as sfn from '@aws-cdk/aws-stepfunctions';
import { Duration } from '@aws-cdk/core';
/**
 * (deprecated) Properties for RunGlueJobTask.
 *
 * @deprecated use `GlueStartJobRun`
 */
export interface RunGlueJobTaskProps {
    /**
     * (deprecated) The service integration pattern indicates different ways to start the Glue job.
     *
     * The valid value for Glue is either FIRE_AND_FORGET or SYNC.
     *
     * @default FIRE_AND_FORGET
     * @deprecated
     */
    readonly integrationPattern?: sfn.ServiceIntegrationPattern;
    /**
     * (deprecated) The job arguments specifically for this run.
     *
     * For this job run, they replace the default arguments set in the job definition itself.
     *
     * @default - Default arguments set in the job definition
     * @deprecated
     */
    readonly arguments?: {
        [key: string]: string;
    };
    /**
     * (deprecated) The job run timeout.
     *
     * This is the maximum time that a job run can consume resources before it is terminated and enters TIMEOUT status.
     * Must be at least 1 minute.
     *
     * @default - Default timeout set in the job definition
     * @deprecated
     */
    readonly timeout?: Duration;
    /**
     * (deprecated) The name of the SecurityConfiguration structure to be used with this job run.
     *
     * This must match the Glue API
     * [single-line string pattern](https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-common.html#aws-glue-api-regex-oneLine).
     *
     * @default - Default configuration set in the job definition
     * @deprecated
     */
    readonly securityConfiguration?: string;
    /**
     * (deprecated) After a job run starts, the number of minutes to wait before sending a job run delay notification.
     *
     * Must be at least 1 minute.
     *
     * @default - Default delay set in the job definition
     * @deprecated
     */
    readonly notifyDelayAfter?: Duration;
}
/**
 * (deprecated) Invoke a Glue job as a Task.
 *
 * OUTPUT: the output of this task is a JobRun structure, for details consult
 * https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-runs.html#aws-glue-api-jobs-runs-JobRun
 *
 * @see https://docs.aws.amazon.com/step-functions/latest/dg/connect-glue.html
 * @deprecated use `GlueStartJobRun`
 */
export declare class RunGlueJobTask implements sfn.IStepFunctionsTask {
    private readonly glueJobName;
    private readonly props;
    private readonly integrationPattern;
    /**
     * @deprecated
     */
    constructor(glueJobName: string, props?: RunGlueJobTaskProps);
    /**
     * (deprecated) (deprecated) Called when the task object is used in a workflow.
     *
     * @deprecated
     */
    bind(task: sfn.Task): sfn.StepFunctionsTaskConfig;
}
